define('dojo/nls/pmbdijit_he-il',{
'dijit/nls/loading':{"loadingState":"טעינה...‏","errorState":"אירעה שגיאה","_localized":{}}
,
'dijit/form/nls/validate':{"invalidMessage":"הערך שצוין אינו חוקי.","missingMessage":"זהו ערך דרוש.","rangeMessage":"הערך מחוץ לטווח.","_localized":{}}
,
'dojo/cldr/nls/number':{"scientificFormat":"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]","infinity":"∞","superscriptingExponent":"×","list":";","percentSign":"%","minusSign":"‎-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000T","currencySpacing-afterCurrency-insertBetween":" ","nan":"NaN","plusSign":"‎+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]","currencyFormat":"#,##0.00 ¤","perMille":"‰","group":",","percentFormat":"#,##0%","decimalFormat-long":"‏000 טריליון","decimalFormat":"#,##0.###","decimal":".","currencySpacing-beforeCurrency-insertBetween":" ","exponential":"E","_localized":{}}
,
'dijit/nls/common':{"buttonOk":"אישור","buttonCancel":"ביטול","buttonSave":"שמירה","itemClose":"סגירה","_localized":{}}
,
'dijit/_editor/nls/commands':{"bold":"מודגש","copy":"העתקה","cut":"גזירה","delete":"מחיקה","indent":"הגדלת כניסה","insertHorizontalRule":"קו אופקי","insertOrderedList":"רשימה ממסופרת","insertUnorderedList":"רשימה עם תבליטים","italic":"נטוי","justifyCenter":"יישור למרכז","justifyFull":"יישור דו-צדדי","justifyLeft":"יישור לימין","justifyRight":"יישור לשמאל","outdent":"הקטנת כניסה","paste":"הדבקה","redo":"שחזור פעולה","removeFormat":"סילוק עיצוב","selectAll":"בחירת הכל","strikethrough":"קו חוצה","subscript":"כתב תחתי","superscript":"כתב עילי","underline":"קו תחתון","undo":"ביטול פעולה","unlink":"סילוק הקישור","createLink":"יצירת קישור","toggleDir":"מיתוג כיוון","insertImage":"הוספת תמונה","insertTable":"הוספת/עריכת טבלה","toggleTableBorder":"מיתוג גבול טבלה","deleteTable":"מחיקת טבלה","tableProp":"תכונת טבלה","htmlToggle":"מקור HTML","foreColor":"צבע חזית","hiliteColor":"צבע רקע","plainFormatBlock":"סגנון פיסקה","formatBlock":"סגנון פיסקה","fontSize":"גודל גופן","fontName":"שם גופן","tabIndent":"כניסת טאב","fullScreen":"מיתוג מסך מלא","viewSource":"הצגת מקור HTML","print":"הדפסה","newPage":"דף חדש","systemShortcut":"הפעולה \"${0}\" זמינה בדפדפן רק באמצעות קיצור דרך במקלדת.  השתמשו בקיצור ${1}.","ctrlKey":"ctrl+${0}‎","appleKey":"⌘${0}‎","_localized":{}}
,
'dijit/form/nls/ComboBox':{"previousMessage":"האפשרויות הקודמות","nextMessage":"אפשרויות נוספות","_localized":{}}
,
'dijit/_editor/nls/FontChoice':{"1":"קטן ביות","2":"קטן מאוד","3":"קטן","4":"בינוני","5":"גדול","6":"גדול מאוד","7":"גדול ביותר","fontSize":"גודל","fontName":"גופן","formatBlock":"עיצוב","serif":"serif","sans-serif":"sans-serif","monospace":"monospace","cursive":"cursive","fantasy":"fantasy","noFormat":"ללא ","p":"פיסקה","h1":"כותרת","h2":"תת-כותרת","h3":"תת-תת-כותרת","pre":"מעוצב מראש","_localized":{}}
,
'dojox/editor/plugins/nls/latinEntities':{"iexcl":"inverted exclamation mark","cent":"cent sign","pound":"pound sign","curren":"currency sign","yen":"yen sign\nyuan sign","brvbar":"broken bar\nbroken vertical bar","sect":"section sign","uml":"diaeresis\nspacing diaeresis","copy":"copyright sign","ordf":"feminine ordinal indicator","laquo":"left-pointing double angle quotation mark\nleft pointing guillemet","not":"not sign","shy":"soft hyphen\ndiscretionary hyphen","reg":"registered sign\nregistered trade mark sign","macr":"macron\nspacing macron\noverline\nAPL overbar","deg":"degree sign","plusmn":"plus-minus sign\nplus-or-minus sign","sup2":"superscript two\nsuperscript digit two\nsquared","sup3":"superscript three\nsuperscript digit three\ncubed","acute":"acute accent\nspacing acute","micro":"micro sign","para":"pilcrow sign\nparagraph sign","middot":"middle dot\nGeorgian comma\nGreek middle dot","cedil":"cedilla\nspacing cedilla","sup1":"superscript one\nsuperscript digit one","ordm":"masculine ordinal indicator","raquo":"right-pointing double angle quotation mark\nright pointing guillemet","frac14":"vulgar fraction one quarter\nfraction one quarter","frac12":"vulgar fraction one half\nfraction one half","frac34":"vulgar fraction three quarters\nfraction three quarters","iquest":"inverted question mark\nturned question mark","Agrave":"Latin capital letter A with grave\nLatin capital letter A grave","Aacute":"Latin capital letter A with acute","Acirc":"Latin capital letter A with circumflex","Atilde":"Latin capital letter A with tilde","Auml":"Latin capital letter A with diaeresis","Aring":"Latin capital letter A with ring above\nLatin capital letter A ring","AElig":"Latin capital letter AE\nLatin capital ligature AE","Ccedil":"Latin capital letter C with cedilla","Egrave":"Latin capital letter E with grave","Eacute":"Latin capital letter E with acute","Ecirc":"Latin capital letter E with circumflex","Euml":"Latin capital letter E with diaeresis","Igrave":"Latin capital letter I with grave","Iacute":"Latin capital letter I with acute","Icirc":"Latin capital letter I with circumflex","Iuml":"Latin capital letter I with diaeresis","ETH":"Latin capital letter ETH","Ntilde":"Latin capital letter N with tilde","Ograve":"Latin capital letter O with grave","Oacute":"Latin capital letter O with acute","Ocirc":"Latin capital letter O with circumflex","Otilde":"Latin capital letter O with tilde","Ouml":"Latin capital letter O with diaeresis","times":"multiplication sign","Oslash":"Latin capital letter O with stroke\nLatin capital letter O slash","Ugrave":"Latin capital letter U with grave","Uacute":"Latin capital letter U with acute","Ucirc":"Latin capital letter U with circumflex","Uuml":"Latin capital letter U with diaeresis","Yacute":"Latin capital letter Y with acute","THORN":"Latin capital letter THORN","szlig":"Latin small letter sharp s\ness-zed","agrave":"Latin small letter a with grave\nLatin small letter a grave","aacute":"Latin small letter a with acute","acirc":"Latin small letter a with circumflex","atilde":"Latin small letter a with tilde","auml":"Latin small letter a with diaeresis","aring":"Latin small letter a with ring above\nLatin small letter a ring","aelig":"Latin small letter ae\nLatin small ligature ae","ccedil":"Latin small letter c with cedilla","egrave":"Latin small letter e with grave","eacute":"Latin small letter e with acute","ecirc":"Latin small letter e with circumflex","euml":"Latin small letter e with diaeresis","igrave":"Latin small letter i with grave","iacute":"Latin small letter i with acute","icirc":"Latin small letter i with circumflex","iuml":"Latin small letter i with diaeresis","eth":"Latin small letter eth","ntilde":"Latin small letter n with tilde","ograve":"Latin small letter o with grave","oacute":"Latin small letter o with acute","ocirc":"Latin small letter o with circumflex","otilde":"Latin small letter o with tilde","ouml":"Latin small letter o with diaeresis","divide":"division sign","oslash":"Latin small letter o with stroke\nLatin small letter o slash","ugrave":"Latin small letter u with grave","uacute":"Latin small letter u with acute","ucirc":"Latin small letter u with circumflex","uuml":"Latin small letter u with diaeresis","yacute":"Latin small letter y with acute","thorn":"Latin small letter thorn","yuml":"Latin small letter y with diaeresis","fnof":"Latin small f with hook\nfunction\nflorin","Alpha":"Greek capital letter alpha","Beta":"Greek capital letter beta","Gamma":"Greek capital letter gamma","Delta":"Greek capital letter delta","Epsilon":"Greek capital letter epsilon","Zeta":"Greek capital letter zeta","Eta":"Greek capital letter eta","Theta":"Greek capital letter theta","Iota":"Greek capital letter iota","Kappa":"Greek capital letter kappa","Lambda":"Greek capital letter lambda","Mu":"Greek capital letter mu","Nu":"Greek capital letter nu","Xi":"Greek capital letter xi","Omicron":"Greek capital letter omicron","Pi":"Greek capital letter pi","Rho":"Greek capital letter rho","Sigma":"Greek capital letter sigma","Tau":"Greek capital letter tau","Upsilon":"Greek capital letter upsilon","Phi":"Greek capital letter phi","Chi":"Greek capital letter chi","Psi":"Greek capital letter psi","Omega":"Greek capital letter omega","alpha":"Greek small letter alpha","beta":"Greek small letter beta","gamma":"Greek small letter gamma","delta":"Greek small letter delta","epsilon":"Greek small letter epsilon","zeta":"Greek small letter zeta","eta":"Greek small letter eta","theta":"Greek small letter theta","iota":"Greek small letter iota","kappa":"Greek small letter kappa","lambda":"Greek small letter lambda","mu":"Greek small letter mu","nu":"Greek small letter nu","xi":"Greek small letter xi","omicron":"Greek small letter omicron","pi":"Greek small letter pi","rho":"Greek small letter rho","sigmaf":"Greek small letter final sigma","sigma":"Greek small letter sigma","tau":"Greek small letter tau","upsilon":"Greek small letter upsilon","phi":"Greek small letter phi","chi":"Greek small letter chi","psi":"Greek small letter psi","omega":"Greek small letter omega","thetasym":"Greek small letter theta symbol","upsih":"Greek upsilon with hook symbol","piv":"Greek pi symbol","bull":"bullet\nblack small circle","hellip":"horizontal ellipsis\nthree dot leader","prime":"prime\nminutes\nfeet","Prime":"double prime\nseconds\ninches","oline":"overline\nspacing overscore","frasl":"fraction slash","weierp":"script capital P\npower set\nWeierstrass p","image":"blackletter capital I\nimaginary part","real":"blackletter capital R\nreal part symbol","trade":"trade mark sign","alefsym":"alef symbol\nfirst transfinite cardinal","larr":"leftwards arrow","uarr":"upwards arrow","rarr":"rightwards arrow","darr":"downwards arrow","harr":"left right arrow","crarr":"downwards arrow with corner leftwards\ncarriage return","lArr":"leftwards double arrow","uArr":"upwards double arrow","rArr":"rightwards double arrow","dArr":"downwards double arrow","hArr":"left right double arrow","forall":"for all","part":"partial differential","exist":"there exists","empty":"empty set\nnull set\ndiameter","nabla":"nabla\nbackward difference","isin":"element of","notin":"not an element of","ni":"contains as member","prod":"n-ary product\nproduct sign","sum":"n-ary sumation","minus":"minus sign","lowast":"asterisk operator","radic":"square root\nradical sign","prop":"proportional to","infin":"infinity","ang":"angle","and":"logical and\nwedge","or":"logical or\nvee","cap":"intersection\ncap","cup":"union\ncup","int":"integral","there4":"therefore","sim":"tilde operator\nvaries with\nsimilar to","cong":"approximately equal to","asymp":"almost equal to\nasymptotic to","ne":"not equal to","equiv":"identical to","le":"less-than or equal to","ge":"greater-than or equal to","sub":"subset of","sup":"superset of","nsub":"not a subset of","sube":"subset of or equal to","supe":"superset of or equal to","oplus":"circled plus\ndirect sum","otimes":"circled times\nvector product","perp":"up tack\northogonal to\nperpendicular","sdot":"dot operator","lceil":"left ceiling\nAPL upstile","rceil":"right ceiling","lfloor":"left floor\nAPL downstile","rfloor":"right floor","lang":"left-pointing angle bracket","rang":"right-pointing angle bracket","loz":"lozenge","spades":"black spade suit","clubs":"black club suit\nshamrock","hearts":"black heart suit\nvalentine","diams":"black diamond suit","OElig":"Latin capital ligature OE","oelig":"Latin small ligature oe","Scaron":"Latin capital letter S with caron","scaron":"Latin small letter s with caron","Yuml":"Latin capital letter Y with diaeresis","circ":"modifier letter circumflex accent","tilde":"small tilde","ensp":"en space","emsp":"em space","thinsp":"thin space","zwnj":"zero width non-joiner","zwj":"zero width joiner","lrm":"left-to-right mark","rlm":"right-to-left mark","ndash":"en dash","mdash":"em dash","lsquo":"left single quotation mark","rsquo":"right single quotation mark","sbquo":"single low-9 quotation mark","ldquo":"left double quotation mark","rdquo":"right double quotation mark","bdquo":"double low-9 quotation mark","dagger":"dagger","Dagger":"double dagger","permil":"per mille sign","lsaquo":"single left-pointing angle quotation mark","rsaquo":"single right-pointing angle quotation mark","euro":"euro sign","_localized":{}}
,
'dojox/editor/plugins/nls/InsertEntity':{"insertEntity":"הוספת סמל ","_localized":{}}
,
'dojo/nls/colors':{"aliceblue":"כחול פלדה","antiquewhite":"לבן עתיק","aqua":"אקווה","aquamarine":"אקוומארין","azure":"תכלת עז","beige":"בז'","bisque":"לבן שקד","black":"שחור","blanchedalmond":"שקד","blue":"כחול","blueviolet":"כחול-סגול","brown":"חום","burlywood":"חום דהוי","cadetblue":"כחול ים","chartreuse":"ירוק-צהוב","chocolate":"שוקולד","coral":"אלמוג","cornflowerblue":"כחול דרדר","cornsilk":"צהבהב","crimson":"ארגמן","cyan":"טורקיז","darkblue":"כחול כהה","darkcyan":"טורקיז כהה","darkgoldenrod":"זהוב כהה","darkgray":"אפור כהה","darkgreen":"ירוק כהה","darkgrey":"אפור כהה","darkkhaki":"חאקי כהה","darkmagenta":"בורדו כהה","darkolivegreen":"ירוק זית כהה","darkorange":"כתום כהה","darkorchid":"סחלב כהה","darkred":"אדום כהה","darksalmon":"סלמון כהה","darkseagreen":"ירוק ים כהה","darkslateblue":"כחול צפחה כהה","darkslategray":"אפור צפחה כהה","darkslategrey":"אפור צפחה כהה","darkturquoise":"טורקיז כהה","darkviolet":"סגול כהה","deeppink":"ורוד עמוק","deepskyblue":"כחול שמיים עמוק","dimgray":"אפור עמום","dimgrey":"אפור עמום","dodgerblue":"כחול","firebrick":"לבנה שרופה","floralwhite":"לבן פרחוני","forestgreen":"ירוק יער","fuchsia":"ורוד בהיר","gainsboro":"גיינסבורו","ghostwhite":"לבן רפאים","gold":"זהב","goldenrod":"זהוב","gray":"אפור","green":"ירוק","greenyellow":"ירוק-צהוב","grey":"אפור","honeydew":"ירקרק","hotpink":"ורוד לוהט","indianred":"אדום דהוי","indigo":"אינדיגו","ivory":"שנהב","khaki":"חאקי","lavender":"לבנדר","lavenderblush":"סומק לבנדר","lawngreen":"ירוק דשא","lemonchiffon":"ירוק לימון","lightblue":"תכלת","lightcoral":"אלמוג בהיר","lightcyan":"טורקיז בהיר","lightgoldenrodyellow":"צהוב בהיר","lightgray":"אפור בהיר","lightgreen":"ירוק בהיר","lightgrey":"אפור בהיר","lightpink":"ורוד בהיר","lightsalmon":"סלמון בהיר","lightseagreen":"ירוק ים בהיר","lightskyblue":"כחול שמיים בהיר","lightslategray":"אפור צפחה בהיר","lightslategrey":"אפור צפחה בהיר","lightsteelblue":"כחול פלדה בהיר","lightyellow":"צהוב בהיר","lime":"לימון","limegreen":"ירוק לימוני","linen":"פשתן","magenta":"בורדו","maroon":"חום אדמדם","mediumaquamarine":"כחול בינוני","mediumblue":"תכלת בינוני","mediumorchid":"סחלב בינוני","mediumpurple":"סגול בינוני","mediumseagreen":"ירוק ים בינוני","mediumslateblue":"כחול צפחה בינוני","mediumspringgreen":"ירוק אביב בינוני","mediumturquoise":"טורקיז בינוני","mediumvioletred":"סגול-אדום בינוני","midnightblue":"כחול כהה","mintcream":"קרם מנטה","mistyrose":"ורוד מעורפל","moccasin":"מוקסין","navajowhite":"לבן נוואחו","navy":"כחול כהה","oldlace":"תחרה עתיקה","olive":"זית","olivedrab":"זית עמום","orange":"כתום","orangered":"כתום אדום","orchid":"סחלב","palegoldenrod":"זהוב בהיר","palegreen":"ירוק בהיר","paleturquoise":"טורקיז בהיר","palevioletred":"סגול-אדום בהיר","papayawhip":"פפאיה","peachpuff":"קציפת אפרסק","peru":"פרו","pink":"ורוד","plum":"שזיף","powderblue":"כחול חיוור","purple":"סגול","red":"אדום","rosybrown":"חום ורדרד","royalblue":"כחול מלכותי","saddlebrown":"חום דהוי","salmon":"סלמון","sandybrown":"חום חולי","seagreen":"ירוק ים","seashell":"צדף","sienna":"סיינה","silver":"כסף","skyblue":"כחול שמיים","slateblue":"כחול צפחה","slategray":"אפור צפחה","slategrey":"אפור צפחה","snow":"שלג","springgreen":"ירוק אביב","steelblue":"כחול פלדה","tan":"חום אדמדם","teal":"כחול-ירוק כהה","thistle":"דרדר","tomato":"עגבניה","transparent":"שקוף","turquoise":"טורקיז","violet":"סגול","wheat":"חיוט","white":"לבן","whitesmoke":"עשן לבן","yellow":"צהוב","yellowgreen":"ירוק צהוב","_localized":{}}
,
'dojox/widget/nls/ColorPicker':{"redLabel":"א","greenLabel":"י","blueLabel":"כ","hueLabel":"ג","saturationLabel":"ר","valueLabel":"ע","degLabel":"°","hexLabel":"הקס","huePickerTitle":"בורר גוון","saturationPickerTitle":"בורר רוויה","_localized":{}}
,
'dojox/editor/plugins/nls/TableDialog':{"insertTableTitle":"הוספת טבלה","modifyTableTitle":"שינוי טבלה","rows":"שורות:","columns":"עמודות:","align":"יישור:","cellPadding":"ריפוד תאים:","cellSpacing":"ריווח תאים:","tableWidth":"רוחב טבלה:","backgroundColor":"צבע רקע:","borderColor":"צבע גבול:","borderThickness":"עובי גבול:","percent":"אחוז","pixels":"פיקסלים","default":"ברירת מחדל","left":"ימין","center":"מרכז","right":"שמאל","buttonSet":"הגדרה","buttonInsert":"הוספה","buttonCancel":"ביטול","selectTableLabel":"בחירת טבלה","insertTableRowBeforeLabel":"הוספת שורה לפני","insertTableRowAfterLabel":"הוספת שורה אחרי","insertTableColumnBeforeLabel":"הוספת עמודה לפני","insertTableColumnAfterLabel":"הוספת עמודה אחרי","deleteTableRowLabel":"מחיקת שורה","deleteTableColumnLabel":"מחיקת עמודה","colorTableCellTitle":"צבע רקע של תא בטבלה","tableContextMenuTitle":"תפריט הקשר של טבלה","_localized":{}}
,
'dojox/editor/plugins/nls/PasteFromWord':{"pasteFromWord":"הדבקה מתוך Word","instructions":"הדביקו את התוכן מתוך Word לתוך תיבת התמליל למטה. לאחר שתהיו מרוצים מהתוכן להוספה, לחצו על לחצן ההדבקה. כדי לבטל את הוספת התמליל, לחצו על לחצן הביטול. ","_localized":{}}
,
'dojox/editor/plugins/nls/InsertAnchor':{"insertAnchor":"הוספת עוגן ","title":"תכונות עוגן ","anchor":"שם:","text":"תיאור:","set":"הגדרה","cancel":"ביטול","_localized":{}}
,
'dojox/editor/plugins/nls/Blockquote':{"blockquote":"ציטוט","_localized":{}}
,
'dojox/editor/plugins/nls/LocalImage':{"insertImageTitle":"הוספת תמונה","url":"תמונה","browse":"עיון...‏ ","text":"תיאור ","set":"הוספה","invalidMessage":"סוג קובץ תמונה לא חוקי","prePopuTextUrl":"ציינו URL של תמונה","prePopuTextBrowse":" או נווטו לקובץ מקומי. ","_localized":{}}
});